@@ -1,10 +1,10 @@
 package Mail::AuthenticationResults::Header;
 # ABSTRACT: Class modelling the Entire Authentication Results Header set
 
-require 5.010;
+require 5.008;
 use strict;
 use warnings;
-our $VERSION = '1.20180211'; # VERSION
+our $VERSION = '1.20180215'; # VERSION
 use Carp;
 
 use Mail::AuthenticationResults::Header::AuthServID;
@@ -32,7 +32,8 @@ sub set_indent_by {
 
 sub indent_by {
     my ( $self ) = @_;
-    return $self->{ 'indent_by'} // 4;
+    return 4 if ! defined $self->{ 'indent_by' }; #5.8
+    return $self->{ 'indent_by'};
 }
 
 
@@ -53,13 +54,16 @@ sub clear_indent_on {
 sub indent_on {
     my ( $self, $type ) = @_;
     if ( $type eq 'Mail::AuthenticationResults::Header::Entry' ) {
-        return $self->{ 'indent_type_' . $type } // 1;
+        return 1 if ! defined $self->{ 'indent_type_' . $type }; #5.8
+        return $self->{ 'indent_type_' . $type };
     }
     if ( $type eq 'Mail::AuthenticationResults::Header::SubEntry' ) {
-        return $self->{ 'indent_type_' . $type } // 0;
+        return 0 if ! defined $self->{ 'indent_type_' . $type }; #5.8
+        return $self->{ 'indent_type_' . $type };
     }
     elsif ( $type eq 'Mail::AuthenticationResults::Header::Comment' ) {
-        return $self->{ 'indent_type_' . $type } // 0;
+        return 0 if ! defined $self->{ 'indent_type_' . $type }; #5.8
+        return $self->{ 'indent_type_' . $type };
     }
     return 0;
 }
@@ -79,7 +83,8 @@ sub set_eol {
 
 sub eol {
     my ( $self ) = @_;
-    return $self->{ 'eol' } // "\n";
+    return "\n" if ! defined $self->{ 'eol' }; #5.8
+    return $self->{ 'eol' };
 }
 
 
@@ -181,7 +186,7 @@ Mail::AuthenticationResults::Header - Class modelling the Entire Authentication
 
 =head1 VERSION
 
-version 1.20180211
+version 1.20180215
 
 =head1 DESCRIPTION
 
