@@ -1,10 +1,10 @@
 package Mail::AuthenticationResults::Header::Base;
 # ABSTRACT: Base class for modelling parts of the Authentication Results Header
 
-require 5.010;
+require 5.008;
 use strict;
 use warnings;
-our $VERSION = '1.20180211'; # VERSION
+our $VERSION = '1.20180215'; # VERSION
 use Scalar::Util qw{ weaken refaddr };
 use Carp;
 
@@ -44,7 +44,8 @@ sub set_key {
 sub key {
     my ( $self ) = @_;
     croak 'Does not have key' if ! $self->_HAS_KEY();
-    return $self->{ 'key' } // q{};
+    return q{} if ! defined $self->{ 'key' }; #5.8
+    return $self->{ 'key' };
 }
 
 
@@ -87,13 +88,15 @@ sub set_value {
 sub value {
     my ( $self ) = @_;
     croak 'Does not have value' if ! $self->_HAS_VALUE();
-    return $self->{ 'value' } // q{};
+    return q{} if ! defined $self->{ 'value' }; # 5.8
+    return $self->{ 'value' };
 }
 
 
 sub stringify {
     my ( $self, $value ) = @_;
-    my $string = $value // q{};
+    my $string = $value;
+    $string = q{} if ! defined $string; #5.8;
 
     if ( $string =~ /[\s\t \(\);=]/ ) {
         $string = '"' . $string . '"';
@@ -106,7 +109,8 @@ sub stringify {
 sub children {
     my ( $self ) = @_;
     croak 'Does not have children' if ! $self->_HAS_CHILDREN();
-    return $self->{ 'children' } // [];
+    return [] if ! defined $self->{ 'children' }; #5.8
+    return $self->{ 'children' };
 }
 
 
@@ -295,7 +299,7 @@ Mail::AuthenticationResults::Header::Base - Base class for modelling parts of th
 
 =head1 VERSION
 
-version 1.20180211
+version 1.20180215
 
 =head1 DESCRIPTION
 
